import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "monocdk-experiment",
    "1.61.0",
    __name__[0:-6],
    "monocdk-experiment@1.61.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
